# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hedgehog/protocol/proto/analog.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='hedgehog/protocol/proto/analog.proto',
  package='hedgehog.protocol.proto',
  syntax='proto3',
  serialized_pb=_b('\n$hedgehog/protocol/proto/analog.proto\x12\x17hedgehog.protocol.proto\"\x1d\n\rAnalogRequest\x12\x0c\n\x04port\x18\x01 \x01(\r\"+\n\x0c\x41nalogUpdate\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\r\"1\n\x11\x41nalogStateAction\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\x0e\n\x06pullup\x18\x02 \x01(\x08\x62\x06proto3')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_ANALOGREQUEST = _descriptor.Descriptor(
  name='AnalogRequest',
  full_name='hedgehog.protocol.proto.AnalogRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.AnalogRequest.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=94,
)


_ANALOGUPDATE = _descriptor.Descriptor(
  name='AnalogUpdate',
  full_name='hedgehog.protocol.proto.AnalogUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.AnalogUpdate.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='hedgehog.protocol.proto.AnalogUpdate.value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=96,
  serialized_end=139,
)


_ANALOGSTATEACTION = _descriptor.Descriptor(
  name='AnalogStateAction',
  full_name='hedgehog.protocol.proto.AnalogStateAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.AnalogStateAction.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pullup', full_name='hedgehog.protocol.proto.AnalogStateAction.pullup', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=190,
)

DESCRIPTOR.message_types_by_name['AnalogRequest'] = _ANALOGREQUEST
DESCRIPTOR.message_types_by_name['AnalogUpdate'] = _ANALOGUPDATE
DESCRIPTOR.message_types_by_name['AnalogStateAction'] = _ANALOGSTATEACTION

AnalogRequest = _reflection.GeneratedProtocolMessageType('AnalogRequest', (_message.Message,), dict(
  DESCRIPTOR = _ANALOGREQUEST,
  __module__ = 'hedgehog.protocol.proto.analog_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.AnalogRequest)
  ))
_sym_db.RegisterMessage(AnalogRequest)

AnalogUpdate = _reflection.GeneratedProtocolMessageType('AnalogUpdate', (_message.Message,), dict(
  DESCRIPTOR = _ANALOGUPDATE,
  __module__ = 'hedgehog.protocol.proto.analog_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.AnalogUpdate)
  ))
_sym_db.RegisterMessage(AnalogUpdate)

AnalogStateAction = _reflection.GeneratedProtocolMessageType('AnalogStateAction', (_message.Message,), dict(
  DESCRIPTOR = _ANALOGSTATEACTION,
  __module__ = 'hedgehog.protocol.proto.analog_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.AnalogStateAction)
  ))
_sym_db.RegisterMessage(AnalogStateAction)


# @@protoc_insertion_point(module_scope)
