# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hedgehog/protocol/proto/motor.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hedgehog.protocol.proto import subscription_pb2 as hedgehog_dot_protocol_dot_proto_dot_subscription__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hedgehog/protocol/proto/motor.proto',
  package='hedgehog.protocol.proto',
  syntax='proto3',
  serialized_pb=_b('\n#hedgehog/protocol/proto/motor.proto\x12\x17hedgehog.protocol.proto\x1a*hedgehog/protocol/proto/subscription.proto\"\xcf\x01\n\x0bMotorAction\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\x32\n\x05state\x18\x02 \x01(\x0e\x32#.hedgehog.protocol.proto.MotorState\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x11\x12:\n\rreached_state\x18\x04 \x01(\x0e\x32#.hedgehog.protocol.proto.MotorState\x12\x12\n\x08relative\x18\x05 \x01(\x11H\x00\x12\x12\n\x08\x61\x62solute\x18\x06 \x01(\x11H\x00\x42\n\n\x08position\"\xa4\x01\n\x13MotorCommandMessage\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\x32\n\x05state\x18\x02 \x01(\x0e\x32#.hedgehog.protocol.proto.MotorState\x12\x0e\n\x06\x61mount\x18\x03 \x01(\x11\x12;\n\x0csubscription\x18\x04 \x01(\x0b\x32%.hedgehog.protocol.proto.Subscription\"\x82\x01\n\x11MotorStateMessage\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\x10\n\x08velocity\x18\x02 \x01(\x11\x12\x10\n\x08position\x18\x03 \x01(\x11\x12;\n\x0csubscription\x18\x04 \x01(\x0b\x32%.hedgehog.protocol.proto.Subscription\"8\n\x16MotorSetPositionAction\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\x10\n\x08position\x18\x02 \x01(\x11*0\n\nMotorState\x12\t\n\x05POWER\x10\x00\x12\t\n\x05\x42RAKE\x10\x01\x12\x0c\n\x08VELOCITY\x10\x02\x42)\n\x1f\x61t.pria.hedgehog.protocol.protoB\x06MotorPb\x06proto3')
  ,
  dependencies=[hedgehog_dot_protocol_dot_proto_dot_subscription__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_MOTORSTATE = _descriptor.EnumDescriptor(
  name='MotorState',
  full_name='hedgehog.protocol.proto.MotorState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='POWER', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BRAKE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VELOCITY', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=676,
  serialized_end=724,
)
_sym_db.RegisterEnumDescriptor(_MOTORSTATE)

MotorState = enum_type_wrapper.EnumTypeWrapper(_MOTORSTATE)
POWER = 0
BRAKE = 1
VELOCITY = 2



_MOTORACTION = _descriptor.Descriptor(
  name='MotorAction',
  full_name='hedgehog.protocol.proto.MotorAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.MotorAction.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='hedgehog.protocol.proto.MotorAction.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='hedgehog.protocol.proto.MotorAction.amount', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reached_state', full_name='hedgehog.protocol.proto.MotorAction.reached_state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='relative', full_name='hedgehog.protocol.proto.MotorAction.relative', index=4,
      number=5, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='absolute', full_name='hedgehog.protocol.proto.MotorAction.absolute', index=5,
      number=6, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='position', full_name='hedgehog.protocol.proto.MotorAction.position',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=109,
  serialized_end=316,
)


_MOTORCOMMANDMESSAGE = _descriptor.Descriptor(
  name='MotorCommandMessage',
  full_name='hedgehog.protocol.proto.MotorCommandMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.MotorCommandMessage.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='hedgehog.protocol.proto.MotorCommandMessage.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='amount', full_name='hedgehog.protocol.proto.MotorCommandMessage.amount', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subscription', full_name='hedgehog.protocol.proto.MotorCommandMessage.subscription', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=319,
  serialized_end=483,
)


_MOTORSTATEMESSAGE = _descriptor.Descriptor(
  name='MotorStateMessage',
  full_name='hedgehog.protocol.proto.MotorStateMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.MotorStateMessage.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='velocity', full_name='hedgehog.protocol.proto.MotorStateMessage.velocity', index=1,
      number=2, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position', full_name='hedgehog.protocol.proto.MotorStateMessage.position', index=2,
      number=3, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subscription', full_name='hedgehog.protocol.proto.MotorStateMessage.subscription', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=486,
  serialized_end=616,
)


_MOTORSETPOSITIONACTION = _descriptor.Descriptor(
  name='MotorSetPositionAction',
  full_name='hedgehog.protocol.proto.MotorSetPositionAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.MotorSetPositionAction.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position', full_name='hedgehog.protocol.proto.MotorSetPositionAction.position', index=1,
      number=2, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=618,
  serialized_end=674,
)

_MOTORACTION.fields_by_name['state'].enum_type = _MOTORSTATE
_MOTORACTION.fields_by_name['reached_state'].enum_type = _MOTORSTATE
_MOTORACTION.oneofs_by_name['position'].fields.append(
  _MOTORACTION.fields_by_name['relative'])
_MOTORACTION.fields_by_name['relative'].containing_oneof = _MOTORACTION.oneofs_by_name['position']
_MOTORACTION.oneofs_by_name['position'].fields.append(
  _MOTORACTION.fields_by_name['absolute'])
_MOTORACTION.fields_by_name['absolute'].containing_oneof = _MOTORACTION.oneofs_by_name['position']
_MOTORCOMMANDMESSAGE.fields_by_name['state'].enum_type = _MOTORSTATE
_MOTORCOMMANDMESSAGE.fields_by_name['subscription'].message_type = hedgehog_dot_protocol_dot_proto_dot_subscription__pb2._SUBSCRIPTION
_MOTORSTATEMESSAGE.fields_by_name['subscription'].message_type = hedgehog_dot_protocol_dot_proto_dot_subscription__pb2._SUBSCRIPTION
DESCRIPTOR.message_types_by_name['MotorAction'] = _MOTORACTION
DESCRIPTOR.message_types_by_name['MotorCommandMessage'] = _MOTORCOMMANDMESSAGE
DESCRIPTOR.message_types_by_name['MotorStateMessage'] = _MOTORSTATEMESSAGE
DESCRIPTOR.message_types_by_name['MotorSetPositionAction'] = _MOTORSETPOSITIONACTION
DESCRIPTOR.enum_types_by_name['MotorState'] = _MOTORSTATE

MotorAction = _reflection.GeneratedProtocolMessageType('MotorAction', (_message.Message,), dict(
  DESCRIPTOR = _MOTORACTION,
  __module__ = 'hedgehog.protocol.proto.motor_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.MotorAction)
  ))
_sym_db.RegisterMessage(MotorAction)

MotorCommandMessage = _reflection.GeneratedProtocolMessageType('MotorCommandMessage', (_message.Message,), dict(
  DESCRIPTOR = _MOTORCOMMANDMESSAGE,
  __module__ = 'hedgehog.protocol.proto.motor_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.MotorCommandMessage)
  ))
_sym_db.RegisterMessage(MotorCommandMessage)

MotorStateMessage = _reflection.GeneratedProtocolMessageType('MotorStateMessage', (_message.Message,), dict(
  DESCRIPTOR = _MOTORSTATEMESSAGE,
  __module__ = 'hedgehog.protocol.proto.motor_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.MotorStateMessage)
  ))
_sym_db.RegisterMessage(MotorStateMessage)

MotorSetPositionAction = _reflection.GeneratedProtocolMessageType('MotorSetPositionAction', (_message.Message,), dict(
  DESCRIPTOR = _MOTORSETPOSITIONACTION,
  __module__ = 'hedgehog.protocol.proto.motor_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.MotorSetPositionAction)
  ))
_sym_db.RegisterMessage(MotorSetPositionAction)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\037at.pria.hedgehog.protocol.protoB\006MotorP'))
# @@protoc_insertion_point(module_scope)
