# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hedgehog/protocol/proto/servo.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from hedgehog.protocol.proto import subscription_pb2 as hedgehog_dot_protocol_dot_proto_dot_subscription__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hedgehog/protocol/proto/servo.proto',
  package='hedgehog.protocol.proto',
  syntax='proto3',
  serialized_pb=_b('\n#hedgehog/protocol/proto/servo.proto\x12\x17hedgehog.protocol.proto\x1a*hedgehog/protocol/proto/subscription.proto\"=\n\x0bServoAction\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\x0e\n\x06\x61\x63tive\x18\x02 \x01(\x08\x12\x10\n\x08position\x18\x03 \x01(\r\"\x82\x01\n\x13ServoCommandMessage\x12\x0c\n\x04port\x18\x01 \x01(\r\x12\x0e\n\x06\x61\x63tive\x18\x02 \x01(\x08\x12\x10\n\x08position\x18\x03 \x01(\r\x12;\n\x0csubscription\x18\x04 \x01(\x0b\x32%.hedgehog.protocol.proto.SubscriptionB)\n\x1f\x61t.pria.hedgehog.protocol.protoB\x06ServoPb\x06proto3')
  ,
  dependencies=[hedgehog_dot_protocol_dot_proto_dot_subscription__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_SERVOACTION = _descriptor.Descriptor(
  name='ServoAction',
  full_name='hedgehog.protocol.proto.ServoAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.ServoAction.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='active', full_name='hedgehog.protocol.proto.ServoAction.active', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position', full_name='hedgehog.protocol.proto.ServoAction.position', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=169,
)


_SERVOCOMMANDMESSAGE = _descriptor.Descriptor(
  name='ServoCommandMessage',
  full_name='hedgehog.protocol.proto.ServoCommandMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='hedgehog.protocol.proto.ServoCommandMessage.port', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='active', full_name='hedgehog.protocol.proto.ServoCommandMessage.active', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position', full_name='hedgehog.protocol.proto.ServoCommandMessage.position', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subscription', full_name='hedgehog.protocol.proto.ServoCommandMessage.subscription', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=302,
)

_SERVOCOMMANDMESSAGE.fields_by_name['subscription'].message_type = hedgehog_dot_protocol_dot_proto_dot_subscription__pb2._SUBSCRIPTION
DESCRIPTOR.message_types_by_name['ServoAction'] = _SERVOACTION
DESCRIPTOR.message_types_by_name['ServoCommandMessage'] = _SERVOCOMMANDMESSAGE

ServoAction = _reflection.GeneratedProtocolMessageType('ServoAction', (_message.Message,), dict(
  DESCRIPTOR = _SERVOACTION,
  __module__ = 'hedgehog.protocol.proto.servo_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.ServoAction)
  ))
_sym_db.RegisterMessage(ServoAction)

ServoCommandMessage = _reflection.GeneratedProtocolMessageType('ServoCommandMessage', (_message.Message,), dict(
  DESCRIPTOR = _SERVOCOMMANDMESSAGE,
  __module__ = 'hedgehog.protocol.proto.servo_pb2'
  # @@protoc_insertion_point(class_scope:hedgehog.protocol.proto.ServoCommandMessage)
  ))
_sym_db.RegisterMessage(ServoCommandMessage)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\037at.pria.hedgehog.protocol.protoB\006ServoP'))
# @@protoc_insertion_point(module_scope)
